@@ -70,10 +70,27 @@ function restart()
   gAppStartup.quit(gAppStartup.eRestart | gAppStartup.eAttemptQuit);
 }
 
+function String_startsWith (base, str)
+{
+  return (base.match("^"+str)==str);
+}
+
 function checkUpdate()
 {
   var resReqFile = Components.classes["@mozilla.org/file/local;1"].createInstance(Components.interfaces.nsILocalFile);
-  resReqFile.initWithPath("/var/lib/update-notifier/user.d/firefox-3.0-restart-required");
+  var launcher = Components.classes["@mozilla.org/process/environment;1"].getService(Components.interfaces.nsIEnvironment).get("MOZ_APP_LAUNCHER");
+  if(launcher == null) {
+    return;
+  }
+
+  try {
+    // If the launcher is a full path, just get the basename
+    resReqFile.initWithPath(launcher);
+    launcher = resReqFile.leafName;
+  } catch (e) { // initWithPath will throw if the path is relative
+  }
+
+  resReqFile.initWithPath("/var/run/" + launcher + "-restart-required");
 
   if(resReqFile.exists())
   {
@@ -103,5 +120,5 @@ function scheduleCheckForUpdate()
 {
   getAndSetTimeBase ();
   if (!intervalID)
-    intervalID = setInterval("checkUpdate()", 10000);
+    intervalID = setInterval("checkUpdate()", 5000);
 }
