@@ -39,13 +39,14 @@ echo -- Inserting Data ...
 echo
 echo
 
-distributionIDs="8.04 8.10 9.04 9.10"
+distributionIDs="8.04 8.10 9.04 9.10 10.04"
 
 archs_7_10="amd64 i386 powerpc sparc"
 archs_8_04="amd64 i386"
 archs_8_10="amd64 i386"
 archs_9_04="amd64 i386"
 archs_9_10="amd64 i386"
+archs_10_04="amd64 i386"
 
 for distro in $distributionIDs; do
 
